@@ -148,7 +148,7 @@ class _ChunksUploader:
         )
         try:
             headers = {
-                "X-Project": self._project_id,
+                "X-Project": str(self._project_id),
                 "X-Api-Key": self._api_key,
                 "X-file-chunk": "{}/{}".format(chunk_number, self.number_of_chunks),
                 "X-file-hash": self._chunker.file_hash,
